@@ -2,26 +2,17 @@
 #define ACCOUNTSDIALOG_H
 
 #include <QDialog>
-#include <QStandardItemModel>
 #include <QModelIndex>
 
 class AccountsDialog : public QDialog
 {
         Q_OBJECT
  public:
-        AccountsDialog(QStandardItemModel *accounts,
-                       QWidget *parent = 0,
+        AccountsDialog(QWidget *parent = 0,
                        Qt::WindowFlags f = 0);
-        ~AccountsDialog();
 
  signals:
         void newAccountSelected();
         void accountDetailsSelected(const QModelIndex &index);
-
- private slots:
-        void newSelected();
-        void detailsSelected(const QModelIndex &index);
-
- private:
 };
 #endif
