@@ -2,26 +2,17 @@
 #define CONCEPTSDIALOG_H
 
 #include <QDialog>
-#include <QStandardItemModel>
 #include <QModelIndex>
 
 class ConceptsDialog : public QDialog
 {
         Q_OBJECT
  public:
-        ConceptsDialog(QStandardItemModel *concepts,
-                       QWidget *parent = 0,
+        ConceptsDialog(QWidget *parent = 0,
                        Qt::WindowFlags f = 0);
-        ~ConceptsDialog();
 
  signals:
         void newConceptSelected();
         void conceptDetailsSelected(const QModelIndex &index);
-
- private slots:
-        void newSelected();
-        void detailsSelected(const QModelIndex &index);
-
- private:
 };
 #endif
