@@ -1,21 +1,35 @@
 #include <QDebug>
-#include <QMaemo5InformationBox>
 #include <QStandardItem>
 #include <QDir>
-#include <QDebug>
-#include "expensedetailsdialog.h"
-#include "scheduleddetailsdialog.h"
-#include "budgetdialog.h"
-#include "conceptsdialog.h"
-#include "conceptdetailsdialog.h"
-#include "expenseslist.h"
 #include "controller.h"
-#include "scheduledlist.h"
-#include "confirmationdialog.h"
-#include "summarywindow.h"
-#include "datechooserdialog.h"
-#include "accountsdialog.h"
-#include "accountdetailsdialog.h"
+
+#ifdef Q_WS_MAEMO_5
+#include "maemo/accountdetailsdialogmaemo.h"
+#include "maemo/accountsdialogmaemo.h"
+#include "maemo/budgetdialogmaemo.h"
+#include "maemo/conceptdetailsdialogmaemo.h"
+#include "maemo/conceptsdialogmaemo.h"
+#include "maemo/confirmationdialogmaemo.h"
+#include "maemo/expensedetailsdialogmaemo.h"
+#include "maemo/scheduleddetailsdialogmaemo.h"
+#include "maemo/scheduledlistmaemo.h"
+#include "maemo/summarywindowmaemo.h"
+#include "maemo/expenseslistmaemo.h"
+#include "maemo/mainwindowmaemo.h"
+#else
+#include "desktop/mainwindowdesktop.h"
+#include "desktop/accountsdialogdesktop.h"
+#include "desktop/accountdetailsdialogdesktop.h"
+#include "desktop/budgetdialogdesktop.h"
+#include "desktop/conceptsdialogdesktop.h"
+#include "desktop/conceptdetailsdialogdesktop.h"
+#include "desktop/confirmationdialogdesktop.h"
+#include "desktop/expenseslistdesktop.h"
+#include "desktop/scheduledlistdesktop.h"
+#include "desktop/expensedetailsdialogdesktop.h"
+#include "desktop/scheduleddetailsdialogdesktop.h"
+#include "desktop/summarywindowdesktop.h"
+#endif
 
 Controller::Controller()
 {
@@ -24,9 +38,19 @@ Controller::Controller()
         configFile.append(QDir::separator()).append(CONFIG_FILENAME);
 
         settings = new QSettings (configFile, QSettings::NativeFormat, this);
-        concepts = new QStandardItemModel(0, 0, this);
-        accounts = new QStandardItemModel(0, 4, this);
+        concepts = new QStandardItemModel(0, 2, this);
         scheduled = new QStandardItemModel(0, 7, this);
+        accounts = new QStandardItemModel(0, 4, this);
+
+#ifdef Q_WS_MAEMO_5
+        mainWindow = new MainWindowMaemo();
+#else
+        mainWindow = new MainWindowDesktop();
+        createModelHeaders();
+#endif
+
+
+        mainWindow->show();
 
         loadConcepts();
         loadAccounts();
@@ -36,7 +60,7 @@ Controller::Controller()
 
         if (accounts->rowCount() == 0) {
                 /* no accounts in the database */
-                QMaemo5InformationBox::information(&mainWindow, tr("You must create an account to be able to write down expenses"));
+                mainWindow->message(tr("You must create an account to be able to write down expenses"));
         } else {
                 int activeAccountId = settings->value(ACTIVE_ACCOUNT_KEY, 0).toInt();
                 QList<QStandardItem*> list = accounts->findItems(QString("%1").arg(activeAccountId),
@@ -44,7 +68,7 @@ Controller::Controller()
                                                                  0);
                 if (list.size() == 0) {
                         /* can only happen if the account is manually deleted from the database */
-                        QMaemo5InformationBox::information(&mainWindow, tr("There's no valid account selected"));
+                        mainWindow->message(tr("There's no valid account selected"));
                 } else {
                         int row = list[0]->index().row();
                         activeAccount = new Account(accounts->item(row, 0)->text().toInt(),
@@ -58,48 +82,44 @@ Controller::Controller()
                         month = new MonthData(QDate::currentDate(), activeAccount, this);
                         loadMonth();
 
-                        mainWindow.setMonthData(month);
+                        mainWindow->setMonthData(month);
                 }
         }
 
-        connect(&mainWindow, SIGNAL(previousMonth()), this, SLOT(previousMonth()));
-        connect(&mainWindow, SIGNAL(nextMonth()), this, SLOT(nextMonth()));
-        connect(&mainWindow, SIGNAL(addExpenseSelected()), this, SLOT(newExpenseSelected()));
-        connect(&mainWindow, SIGNAL(budgetSelected()), this, SLOT(budgetSelected()));
-        connect(&mainWindow, SIGNAL(accountsSelected()), this, SLOT(accountsSelected()));
-        connect(&mainWindow, SIGNAL(conceptsSelected()), this, SLOT(conceptsSelected()));
-        connect(&mainWindow, SIGNAL(expensesSelected()), this, SLOT(expensesSelected()));
-        connect(&mainWindow, SIGNAL(scheduledSelected()), this, SLOT(scheduledSelected()));
-        connect(&mainWindow, SIGNAL(summarySelected()), this, SLOT(summarySelected()));
+        connect(mainWindow, SIGNAL(previousMonth()), this, SLOT(previousMonth()));
+        connect(mainWindow, SIGNAL(nextMonth()), this, SLOT(nextMonth()));
+        connect(mainWindow, SIGNAL(addExpenseSelected()), this, SLOT(newExpenseSelected()));
+        connect(mainWindow, SIGNAL(budgetSelected()), this, SLOT(budgetSelected()));
+        connect(mainWindow, SIGNAL(accountsSelected()), this, SLOT(accountsSelected()));
+        connect(mainWindow, SIGNAL(conceptsSelected()), this, SLOT(conceptsSelected()));
+        connect(mainWindow, SIGNAL(expensesSelected()), this, SLOT(expensesSelected()));
+        connect(mainWindow, SIGNAL(scheduledSelected()), this, SLOT(scheduledSelected()));
+        connect(mainWindow, SIGNAL(summarySelected()), this, SLOT(summarySelected()));
 }
 
 Controller::~Controller()
 {
-}
-
-void Controller::runApp()
-{
-        mainWindow.show();
+        delete mainWindow;
 }
 
 void Controller::previousMonth()
 {
         if (!activeAccount) {
-                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                mainWindow->message(tr("An account must be selected to perform this action"));
                 return;
         }
 
         MonthData *old = month;
         month = new MonthData(old->previous(), activeAccount, this);
         loadMonth();
-        mainWindow.setMonthData(month);
+        mainWindow->setMonthData(month);
         delete old;
 }
 
 void Controller::nextMonth()
 {
         if (!activeAccount) {
-                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                mainWindow->message(tr("An account must be selected to perform this action"));
                 return;
         }
 
@@ -107,10 +127,10 @@ void Controller::nextMonth()
                 MonthData *old = month;
                 month = new MonthData(old->next(), activeAccount, this);
                 loadMonth();
-                mainWindow.setMonthData(month);
+                mainWindow->setMonthData(month);
                 delete old;
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Already at current month"));
+                mainWindow->message(tr("Already at current month"));
         }
 }
 
@@ -118,7 +138,11 @@ void Controller::nextMonth()
 
 void Controller::newAccountSelected()
 {
-        AccountDetailsDialog dialog(&mainWindow);
+#ifdef Q_WS_MAEMO_5
+        AccountDetailsDialogMaemo dialog(mainWindow);
+#else
+        AccountDetailsDialogDesktop dialog(mainWindow);
+#endif
 
         connect(&dialog, SIGNAL(newAccountConfirmed(Account*)), this, SLOT(newAccountConfirmed(Account*)));
 
@@ -145,22 +169,25 @@ void Controller::newAccountConfirmed(Account *a)
                                 loadScheduled();
                                 month = new MonthData(QDate::currentDate(), activeAccount, this);
                                 loadMonth();
-                                mainWindow.setMonthData(month);
+                                mainWindow->setMonthData(month);
                         }
 
                 } else {
-                        QMaemo5InformationBox::information(&mainWindow, tr("Error creating account"));
+                        mainWindow->message(tr("Error creating account"));
                 }
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Account already exists"));
+                mainWindow->message(tr("Account already exists"));
         }
         delete a;
 }
 
 void Controller::accountsSelected()
 {
-        AccountsDialog dialog(accounts, &mainWindow);
-
+#ifdef Q_WS_MAEMO_5
+        AccountsDialogMaemo dialog(accounts, mainWindow);
+#else
+        AccountsDialogDesktop dialog(accounts, mainWindow);
+#endif
         connect(&dialog, SIGNAL(newAccountSelected()), this, SLOT(newAccountSelected()));
         connect(&dialog, SIGNAL(accountDetailsSelected(QModelIndex)), this, SLOT(accountDetailsSelected(QModelIndex)));
 
@@ -169,7 +196,11 @@ void Controller::accountsSelected()
 
 void Controller::accountDetailsSelected(QModelIndex index)
 {
-        AccountDetailsDialog dialog(accounts, index.row(), activeAccount, &mainWindow);
+#ifdef Q_WS_MAEMO_5
+        AccountDetailsDialogMaemo dialog(accounts, index.row(), activeAccount, mainWindow);
+#else
+        AccountDetailsDialogDesktop dialog(accounts, index.row(), activeAccount, mainWindow);
+#endif
 
         connect(&dialog, SIGNAL(deleteAccountConfirmed(Account*)),
                 this, SLOT(deleteAccountConfirmed(Account*)));
@@ -184,20 +215,15 @@ void Controller::accountDetailsSelected(QModelIndex index)
 void Controller::deleteAccountConfirmed(Account *a)
 {
         if (a->id() == activeAccount->id()) {
-                QMaemo5InformationBox::information(&mainWindow, tr("Cannot delete active account"));
+                mainWindow->message(tr("Cannot delete active account"));
                 delete a;
                 return;
         }
 
-        QString message(tr("When deleting an account, all the expenses associated to it "
-                           "will also be deleted\n"
-                           "Are you sure you want to delete the account?"));
-        if (ConfirmationDialog::askConfirmation(message)) {
-                if (db.remove(a)) {
-                        loadAccounts();
-                } else {
-                        QMaemo5InformationBox::information(&mainWindow, tr("Error deleting account"));
-                }
+        if (db.remove(a)) {
+                loadAccounts();
+        } else {
+                mainWindow->message(tr("Error deleting account"));
         }
         delete a;
 }
@@ -207,7 +233,7 @@ void Controller::updateAccountConfirmed(Account *a)
         if (db.update(a)) {
                 loadAccounts();
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Error updating account"));
+                mainWindow->message(tr("Error updating account"));
         }
 
         delete a;
@@ -229,7 +255,7 @@ void Controller::selectAccountConfirmed(Account *a)
         }
         month = new MonthData(QDate::currentDate(), activeAccount, this);
         loadMonth();
-        mainWindow.setMonthData(month);
+        mainWindow->setMonthData(month);
 }
 
 
@@ -238,12 +264,15 @@ void Controller::selectAccountConfirmed(Account *a)
 void Controller::newExpenseSelected()
 {
         if (!activeAccount) {
-                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                mainWindow->message(tr("An account must be selected to perform this action"));
                 return;
         }
 
-        ExpenseDetailsDialog dialog(month->date(), concepts, (QWidget*)QObject::sender());
-
+#ifdef Q_WS_MAEMO_5
+        ExpenseDetailsDialogMaemo dialog(month->date(), concepts, (QWidget*)QObject::sender());
+#else
+        ExpenseDetailsDialogDesktop dialog(month->date(), concepts, (QWidget*)QObject::sender());
+#endif
         connect(&dialog, SIGNAL(newExpenseConfirmed(Expense*)), this, SLOT(newExpenseConfirmed(Expense*)));
 
         dialog.exec();
@@ -260,11 +289,15 @@ void Controller::newExpenseConfirmed(Expense *e)
 void Controller::expensesSelected()
 {
         if (!activeAccount) {
-                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                mainWindow->message(tr("An account must be selected to perform this action"));
                 return;
         }
 
-        ExpensesList *list = new ExpensesList (month->expenses(), &mainWindow);
+#ifdef Q_WS_MAEMO_5
+        ExpensesList *list = new ExpensesListMaemo (month->expenses(), mainWindow);
+#else
+        ExpensesList *list = new ExpensesListDesktop (month->expenses(), mainWindow);
+#endif
 
         connect(list, SIGNAL(newExpenseSelected()), this, SLOT(newExpenseSelected()));
         connect(list, SIGNAL(expenseDetailsSelected(QModelIndex)), this, SLOT(expenseDetailsSelected(QModelIndex)));
@@ -275,7 +308,11 @@ void Controller::expensesSelected()
 
 void Controller::expenseDetailsSelected(QModelIndex index)
 {
-        ExpenseDetailsDialog dialog(month->date(), concepts, month->expenses(), index.row(), (QWidget*)QObject::sender());
+#ifdef Q_WS_MAEMO_5
+        ExpenseDetailsDialogMaemo dialog(month->date(), concepts, month->expenses(), index.row(), (QWidget*)QObject::sender());
+#else
+        ExpenseDetailsDialogDesktop dialog(month->date(), concepts, month->expenses(), index.row(), (QWidget*)QObject::sender());
+#endif
 
         connect(&dialog, SIGNAL(deleteExpenseConfirmed(Expense*)),
                 this, SLOT(deleteExpenseConfirmed(Expense*)));
@@ -290,7 +327,7 @@ void Controller::deleteExpenseConfirmed(Expense *e)
         if (db.remove(e)) {
                 loadMonth(true);
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Error deleting expense"));
+                mainWindow->message(tr("Error deleting expense"));
         }
 
         delete e;
@@ -301,7 +338,7 @@ void Controller::updateExpenseConfirmed(Expense *e)
         if (db.update(e)) {
                 loadMonth(true);
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Error updating expense"));
+                mainWindow->message(tr("Error updating expense"));
         }
 
         delete e;
@@ -312,11 +349,15 @@ void Controller::updateExpenseConfirmed(Expense *e)
 void Controller::budgetSelected()
 {
         if (!activeAccount) {
-                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                mainWindow->message(tr("An account must be selected to perform this action"));
                 return;
         }
 
-        BudgetDialog dialog(month->budget(), &mainWindow);
+#ifdef Q_WS_MAEMO_5
+        BudgetDialogMaemo dialog(month->budget(), mainWindow);
+#else
+        BudgetDialogDesktop dialog(month->budget(), mainWindow);
+#endif
 
         connect(&dialog, SIGNAL(changeBudget(double)), this, SLOT(changeBudgetConfirmed(double)));
 
@@ -334,7 +375,11 @@ void Controller::changeBudgetConfirmed (double budget)
 
 void Controller::conceptsSelected()
 {
-        ConceptsDialog dialog(concepts, &mainWindow);
+#ifdef Q_WS_MAEMO_5
+        ConceptsDialogMaemo dialog(concepts, mainWindow);
+#else
+        ConceptsDialogDesktop dialog(concepts, mainWindow);
+#endif
 
         connect(&dialog, SIGNAL(newConceptSelected()), this, SLOT(newConceptSelected()));
         connect(&dialog, SIGNAL(conceptDetailsSelected(QModelIndex)), this, SLOT(conceptDetailsSelected(QModelIndex)));
@@ -344,8 +389,11 @@ void Controller::conceptsSelected()
 
 void Controller::newConceptSelected()
 {
-        ConceptDetailsDialog dialog(&mainWindow);
-
+#ifdef Q_WS_MAEMO_5
+        ConceptDetailsDialogMaemo dialog(mainWindow);
+#else
+        ConceptDetailsDialogDesktop dialog(mainWindow);
+#endif
         connect(&dialog, SIGNAL(newConceptConfirmed(Concept*)), this, SLOT(newConceptConfirmed(Concept*)));
 
         dialog.exec();
@@ -353,8 +401,11 @@ void Controller::newConceptSelected()
 
 void Controller::conceptDetailsSelected(const QModelIndex &index)
 {
-        ConceptDetailsDialog dialog(concepts, index.row(), &mainWindow);
-
+#ifdef Q_WS_MAEMO_5
+        ConceptDetailsDialogMaemo dialog(concepts, index.row(), mainWindow);
+#else
+        ConceptDetailsDialogDesktop dialog(concepts, index.row(), mainWindow);
+#endif
         connect(&dialog, SIGNAL(deleteConceptConfirmed(Concept*)),
                 this, SLOT(deleteConceptConfirmed(Concept*)));
         connect(&dialog, SIGNAL(updateConceptConfirmed(Concept*)),
@@ -369,29 +420,24 @@ void Controller::newConceptConfirmed(Concept *c)
                 if (db.create(c)) {
                         loadConcepts();
                 } else {
-                        QMaemo5InformationBox::information(&mainWindow, tr("Error creating concept"));
+                        mainWindow->message(tr("Error creating concept"));
                 }
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Concept already exists"));
+                mainWindow->message(tr("Concept already exists"));
         }
         delete c;
 }
 
 void Controller::deleteConceptConfirmed(Concept *c)
 {
-        QString message(tr("When deleting a concept, all the expenses associated to it "
-                           "will be assigned an empty concept instead.\n"
-                           "Are you sure you want to delete the concept?"));
-        if (ConfirmationDialog::askConfirmation(message)) {
-                if (db.remove(c)) {
-                        loadConcepts();
-                        if (activeAccount) {
-                                loadScheduled();
-                                loadMonth(true);
-                        }
-                } else {
-                        QMaemo5InformationBox::information(&mainWindow, tr("Error deleting concept"));
+        if (db.remove(c)) {
+                loadConcepts();
+                if (activeAccount) {
+                        loadScheduled();
+                        loadMonth(true);
                 }
+        } else {
+                mainWindow->message(tr("Error deleting concept"));
         }
         delete c;
 }
@@ -401,7 +447,7 @@ void Controller::updateConceptConfirmed(Concept *c)
         if (db.update(c)) {
                 loadConcepts();
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Error updating concept"));
+                mainWindow->message(tr("Error updating concept"));
         }
 
         delete c;
@@ -412,11 +458,15 @@ void Controller::updateConceptConfirmed(Concept *c)
 void Controller::scheduledSelected()
 {
         if (!activeAccount) {
-                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                mainWindow->message(tr("An account must be selected to perform this action"));
                 return;
         }
 
-        ScheduledList *list = new ScheduledList (scheduled, &mainWindow);
+#ifdef Q_WS_MAEMO_5
+        ScheduledListMaemo *list = new ScheduledListMaemo (scheduled, mainWindow);
+#else
+        ScheduledListDesktop *list = new ScheduledListDesktop (scheduled, mainWindow);
+#endif
 
         connect(list, SIGNAL(newScheduledSelected()), this, SLOT(newScheduledSelected()));
         connect(list, SIGNAL(scheduledDetailsSelected(QModelIndex)), this, SLOT(scheduledDetailsSelected(QModelIndex)));
@@ -426,44 +476,50 @@ void Controller::scheduledSelected()
 
 void Controller::newScheduledSelected()
 {
-        ScheduledDetailsDialog dialog(concepts, (QWidget*)QObject::sender());
+#ifdef Q_WS_MAEMO_5
+        ScheduledDetailsDialogMaemo dialog(concepts, (QWidget*)QObject::sender());
+#else
+        ScheduledDetailsDialogDesktop dialog(concepts, (QWidget*)QObject::sender());
+#endif
 
-        connect(&dialog, SIGNAL(newScheduledConfirmed(Expense*)), this, SLOT(newScheduledConfirmed(Expense*)));
+        connect(&dialog, SIGNAL(newScheduledConfirmed(Expense*, bool)), this, SLOT(newScheduledConfirmed(Expense*, bool)));
 
         dialog.exec();
 }
 
 void Controller::scheduledDetailsSelected(QModelIndex index)
 {
-        ScheduledDetailsDialog dialog(concepts, scheduled, index.row(), (QWidget*)QObject::sender());
+#ifdef Q_WS_MAEMO_5
+        ScheduledDetailsDialogMaemo dialog(concepts, scheduled, index.row(), (QWidget*)QObject::sender());
+#else
+        ScheduledDetailsDialogDesktop dialog(concepts, scheduled, index.row(), (QWidget*)QObject::sender());
+#endif
 
         connect(&dialog, SIGNAL(deleteScheduledConfirmed(Expense*)),
                 this, SLOT(deleteScheduledConfirmed(Expense*)));
-        connect(&dialog, SIGNAL(updateScheduledConfirmed(Expense*)),
-                this, SLOT(updateScheduledConfirmed(Expense*)));
+        connect(&dialog, SIGNAL(updateScheduledConfirmed(Expense*, bool)),
+                this, SLOT(updateScheduledConfirmed(Expense*, bool)));
 
         dialog.exec();
 }
 
-void Controller::newScheduledConfirmed(Expense *e)
+void Controller::newScheduledConfirmed(Expense *e, bool createInCurrentMonth)
 {
         if (db.createScheduled(activeAccount->id(), e)) {
                 loadScheduled();
-                if (e->frecuency() & (1 << QDate::currentDate().month() -1)) {
-                        /* current month fits into the just created scheduled expense. Ask the user
-                           if it should be applied to current month */
-                        QString message(tr("Current month fits in the scheduled expense description.\n"
-                                           "Do you want the expense to be created in it?"));
-                        if (ConfirmationDialog::askConfirmation(message)) {
-                                Expense *newExpense = new Expense (0, e->day(), e->amount(), e->concept(), e->description());
-                                db.create(QDate::currentDate().year(), QDate::currentDate().month(),
-                                          activeAccount->id(), newExpense);
-                                loadMonth(true);
-                                delete newExpense;
+                if (createInCurrentMonth) {
+                    for (int day = 1; day <= 31; day++) {
+                        if (e->day()  & (1 << (day - 1))) {
+                            Expense *newExpense = new Expense (0, day, e->amount(), e->concept(), e->description());
+                            db.create(QDate::currentDate().year(), QDate::currentDate().month(),
+                                      activeAccount->id(), newExpense);
+                            delete newExpense;
                         }
+                    }
+                    loadMonth(true);
                 }
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Error creating scheduled expense"));
+                mainWindow->message(tr("Error creating scheduled expense"));
         }
 
         delete e;
@@ -474,38 +530,33 @@ void Controller::deleteScheduledConfirmed(Expense *e)
         if (db.removeScheduled(e)) {
                 loadScheduled();
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Error deleting scheduled expense"));
+                mainWindow->message(tr("Error deleting scheduled expense"));
         }
 
         delete e;
 }
 
-void Controller::updateScheduledConfirmed(Expense *e)
+void Controller::updateScheduledConfirmed(Expense *e, bool createInCurrentMonth)
 {
         /* store the previous frecuency value from the updated scheduled */
         QList<QStandardItem*> list = scheduled->findItems(QString("%1").arg(e->id()),
                                                           Qt::MatchFixedString,
                                                           0);
-        int previousFrecuency = scheduled->item(list[0]->index().row(), 5)->text().toInt();
-
         if (db.updateScheduled(e)) {
                 loadScheduled();
-                if (e->frecuency() & (1 << QDate::currentDate().month() - 1)
-                    && !(previousFrecuency & (1 << QDate::currentDate().month() - 1))) {
-                        /* current month has been added to the scheduled expense in the modification. Ask the user
-                           if it should be applied to current month */
-                        QString message(tr("Current month fits in the scheduled expense description after the modification.\n"
-                                           "Do you want the expense to be created in it?"));
-                        if (ConfirmationDialog::askConfirmation(message)) {
-                                Expense *newExpense = new Expense (0, e->day(), e->amount(), e->concept(), e->description());
-                                db.create(QDate::currentDate().year(), QDate::currentDate().month(),
-                                          activeAccount->id(), newExpense);
-                                loadMonth(true);
-                                delete newExpense;
+                if (createInCurrentMonth) {
+                    for (int day = 1; day <= 31; day++) {
+                        if (e->day()  & (1 << (day - 1))) {
+                            Expense *newExpense = new Expense (0, day, e->amount(), e->concept(), e->description());
+                            db.create(QDate::currentDate().year(), QDate::currentDate().month(),
+                                      activeAccount->id(), newExpense);
+                            delete newExpense;
                         }
+                    }
+                    loadMonth(true);
                 }
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Error updating scheduled expense"));
+                mainWindow->message(tr("Error updating scheduled expense"));
         }
 
         delete e;
@@ -516,21 +567,25 @@ void Controller::updateScheduledConfirmed(Expense *e)
 void Controller::summarySelected()
 {
         if (!activeAccount) {
-                QMaemo5InformationBox::information(&mainWindow, tr("An account must be selected to perform this action"));
+                mainWindow->message(tr("An account must be selected to perform this action"));
                 return;
         }
 
         int minYear, minMonth, maxYear, maxMonth;
 
         if (db.getDataInterval(activeAccount->id(), minYear, minMonth, maxYear, maxMonth)) {
-                summaryWindow = new SummaryWindow(minYear, minMonth, maxYear, maxMonth, &mainWindow);
+#ifdef Q_WS_MAEMO_5
+                summaryWindow = new SummaryWindowMaemo(minYear, minMonth, maxYear, maxMonth, mainWindow);
+#else
+                summaryWindow = new SummaryWindowDesktop(minYear, minMonth, maxYear, maxMonth, mainWindow);
+#endif
 
                 connect (summaryWindow, SIGNAL(periodChanged(int, int, int, int)),
                          this, SLOT(summaryPeriodChanged(int, int, int, int)));
 
                 summaryWindow->show();
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Error loading data interval"));
+                mainWindow->message(tr("Error loading data interval"));
         }
 }
 
@@ -540,7 +595,7 @@ void Controller::summaryPeriodChanged(int startYear, int startMonth, int endYear
         if (db.load(activeAccount->id(), data)) {
                 summaryWindow->setSummaryData(data);
         } else {
-                QMaemo5InformationBox::information(&mainWindow, tr("Error loading interval data"));
+                mainWindow->message(tr("Error loading interval data"));
                 delete data;
         }
 }
@@ -549,6 +604,7 @@ void Controller::summaryPeriodChanged(int startYear, int startMonth, int endYear
 
 void Controller::loadMonth(bool reload)
 {
+        month->enableExpenseNotifications(false);
         if (reload) {
                 month->clear();
                 db.load(month, true);
@@ -561,31 +617,36 @@ void Controller::loadMonth(bool reload)
                         if (month->isCurrent()) {
                                 int i;
                                 for (i = 0; i < scheduled->rowCount(); i++) {
-                                        int frec = scheduled->item(i, 5)->text().toInt();
-                                        if (frec & (1 << month->month() - 1)) {
-                                                /* check if date is valid before creating the expense because of leap years */
-                                                if (QDate::isValid(month->year(),
-                                                                   month->month(),
-                                                                   scheduled->item(i,1)->text().toInt())) {
+                                        int frec = scheduled->item(i, SCHEDULED_MONTH)->text().toInt();
+                                        if (frec & (1 << (month->month() - 1))) {
+                                            for (int day = 1; day <= 31; day++) {
+                                                if (scheduled->item(i, SCHEDULED_DAY)->text().toInt() & (1 << (day - 1))) {
+                                                    /* check if date is valid before creating the expense because of leap years */
+                                                    if (QDate::isValid(month->year(),
+                                                                       month->month(),
+                                                                       day)) {
                                                         Expense *e = new Expense(0,
-                                                                                 scheduled->item(i, 1)->text().toInt(),
-                                                                                 scheduled->item(i, 2)->text().toDouble(),
-                                                                                 scheduled->item(i, 3)->text(),
-                                                                                 scheduled->item(i, 4)->text());
+                                                                                 day,
+                                                                                 scheduled->item(i, SCHEDULED_AMOUNT)->text().toDouble(),
+                                                                                 scheduled->item(i, SCHEDULED_CONCEPT)->text(),
+                                                                                 scheduled->item(i, SCHEDULED_DESCRIPTION)->text());
                                                         db.create(month->year(), month->month(), activeAccount->id(), e);
                                                         delete e;
+                                                    }
                                                 }
+                                            }
                                         }
                                 }
                                 db.load(month, true);
                         }
                 }
         }
+        month->enableExpenseNotifications(true);
 }
 
 void Controller::loadConcepts()
 {
-        concepts->clear();
+        concepts->removeRows(0, concepts->rowCount());
         db.loadConcepts(concepts);
 }
 
@@ -611,3 +672,47 @@ void Controller::loadAccounts()
                 }
         }
 }
+
+void Controller::createModelHeaders()
+{
+        QStandardItem *header;
+
+        /* account model headers */
+        header = new QStandardItem (tr("Id"));
+        header->setTextAlignment(Qt::AlignCenter);
+        accounts->setHorizontalHeaderItem(0, header);
+        header = new QStandardItem (tr("Name"));
+        header->setTextAlignment(Qt::AlignCenter);
+        accounts->setHorizontalHeaderItem(1, header);
+        header = new QStandardItem (tr("Budget"));
+        header->setTextAlignment(Qt::AlignCenter);
+        accounts->setHorizontalHeaderItem(2, header);
+        header = new QStandardItem (tr("Active"));
+        header->setTextAlignment(Qt::AlignCenter);
+        accounts->setHorizontalHeaderItem(3, header);
+
+        /* concepts model headers */
+        header = new QStandardItem (tr("Name"));
+        header->setTextAlignment(Qt::AlignCenter);
+        concepts->setHorizontalHeaderItem(0, header);
+        header = new QStandardItem (tr("Price"));
+        header->setTextAlignment(Qt::AlignCenter);
+        concepts->setHorizontalHeaderItem(1, header);
+
+        /* scheduled model headers */
+        header = new QStandardItem (tr("Day"));
+        header->setTextAlignment(Qt::AlignCenter);
+        scheduled->setHorizontalHeaderItem(SCHEDULED_DAY_AS_STRING, header);
+        header = new QStandardItem (tr("Amount"));
+        header->setTextAlignment(Qt::AlignCenter);
+        scheduled->setHorizontalHeaderItem(SCHEDULED_AMOUNT, header);
+        header = new QStandardItem (tr("Item"));
+        header->setTextAlignment(Qt::AlignCenter);
+        scheduled->setHorizontalHeaderItem(SCHEDULED_CONCEPT, header);
+        header = new QStandardItem (tr("Description"));
+        header->setTextAlignment(Qt::AlignCenter);
+        scheduled->setHorizontalHeaderItem(SCHEDULED_DESCRIPTION, header);
+        header = new QStandardItem (tr("Repeat"));
+        header->setTextAlignment(Qt::AlignCenter);
+        scheduled->setHorizontalHeaderItem(SCHEDULED_MONTH_AS_STRING, header);
+}
