@@ -6,6 +6,8 @@
 #include <QStandardItem>
 #include <QUuid>
 
+#define CURRENT_VERSION 600
+
 
 DBManager::DBManager()
 {
@@ -19,22 +21,18 @@ DBManager::~DBManager()
 
 void DBManager::initDB()
 {
-        bool create;
-
         QString dirPath(QDir::home().path());
         dirPath.append(QDir::separator()).append(DATA_FOLDER);
-
-        QString filePath(dirPath);
-        filePath.append(QDir::separator()).append(DB_FILENAME);
-
-        create = !QDir::home().exists(filePath);
-
         if (!QDir::home().exists(dirPath)) {
                 QDir::home().mkdir(dirPath);
         }
 
+        filePath = dirPath + QDir::separator() + DB_FILENAME;
+
         db = QSqlDatabase::addDatabase("QSQLITE");
         db.setDatabaseName(filePath);
+
+        bool create = !existsDB();
         openDB();
 
         if (create) {
@@ -43,14 +41,207 @@ void DBManager::initDB()
                         qCritical() << "\nError Initializing database! Exiting...";
                         exit(0);
                 }
+        } else {
+                int version = DBVersion();
+                if (version) {
+                        if (version != CURRENT_VERSION) {
+                                updateDB();
+                        } else {
+                                qDebug() << "No need to update database";
+                        }
+                } else {
+                        qDebug() << "Unknown database version... exiting";
+                        exit(1);
+                }
         }
 }
 
+bool DBManager::existsDB()
+{
+        return QDir::home().exists(filePath);
+}
+
+int DBManager::DBVersion()
+{
+        if (!db.tables().contains("account")) {
+                return 300;
+        }
+
+        if (!db.tables().contains("version")) {
+                return 400;
+        }
+
+        bool ret;
+        QSqlQuery query;
+
+        ret = query.exec("select value from version");
+
+        if (!ret || !query.next()) {
+                return 0;
+        }
+
+        return query.value(0).toInt();
+}
+
+void DBManager::updateDB()
+{
+        backupPath = filePath + ".back";
+
+        closeDB();
+        createBackup();
+        openDB();
+
+        int version = DBVersion();
+        bool error = false;
+
+        while (!error && version != CURRENT_VERSION) {
+                switch (version) {
+                case 500:
+                        error = !updateFrom500To600();
+                        break;
+                case 400:
+                        error = !updateFrom400To500();
+                        break;
+                case 300:
+                        qDebug() << "Cannot update from version 0.3";
+                        error = true;
+                        break;
+                default:
+                        qDebug() << "Unrecognized database version";
+                        error = true;
+                }
+                version = DBVersion();
+        }
+
+        closeDB();
+        if (error) {
+                qDebug() << "Error updating database";
+                restoreBackup();
+                exit(1);
+        } else {
+                qDebug() << "Database successfully updated";
+                removeBackup();
+        }
+        openDB();
+}
+
+bool DBManager::updateFrom400To500()
+{
+        bool ret;
+        QSqlQuery query;
+
+        qDebug() << "Updating from version 400 to 500";
+
+        query.exec("begin transaction");
+        ret = query.exec("CREATE TABLE version (value integer primary key)");
+
+        if (!ret) {
+                qDebug() << "Error creating table version " << query.lastError();
+                query.exec("rollback");
+                return false;
+        }
+
+        ret = query.exec("insert into version(value) values(500)");
+        if (!ret) {
+                qDebug() << "Error inserting version value in tha database " << query.lastError();
+                query.exec("rollback");
+                return false;
+        }
+
+        query.exec("commit");
+        return true;
+}
+
+bool DBManager::updateFrom500To600()
+{
+        bool ret;
+        QSqlQuery query;
+        QList<QPair<int, int> > data;
+
+        qDebug() << "Updating from version 500 to 600";
+
+        // start transaction
+        query.exec("begin transaction");
+
+        // convert scheduled day field to contain several values instead of one
+        ret = query.exec("select id, day from scheduled");
+        if (!ret) {
+                qDebug() << "Error reading data from database " << query.lastError();
+                query.exec("rollback");
+                return false;
+        }
+
+        while (query.next()) {
+            QPair<int, int> p(query.value(0).toInt(), 1 << (query.value(1).toInt() - 1));
+            data << p;
+            // data << QPair<int, int>(query.value(0).toInt(), 1 << (query.value(1).toInt() - 1));
+            qDebug() << "replacing day " << query.value(1).toInt() << " with " << p.second;
+        }
+
+        QPair<int, int> pair;
+        foreach (pair, data) {
+            ret = query.exec(QString("update scheduled set day = %1 where id = %2")
+                             .arg(pair.second)
+                             .arg(pair.first));
+            if (!ret) {
+                qDebug() << "Error updating data " << query.lastError();
+                query.exec("rollback");
+                return false;
+            }
+        }
+
+        //set new version
+        ret = query.exec("update version set value = 600");
+        if (!ret) {
+                qDebug() << "Error setting new version to the database " << query.lastError();
+                query.exec("rollback");
+                return false;
+        }
+
+        //commit transaction
+        query.exec("commit");
+
+        return true;
+}
+
+void DBManager::createBackup()
+{
+        qDebug() << "Creating database backup";
+        QFile::copy(filePath, backupPath);
+}
+
+void DBManager::restoreBackup()
+{
+        qDebug() << "Restoring database backup";
+        QFile::remove(filePath);
+        QFile::rename(backupPath, filePath);
+}
+
+void DBManager::removeBackup()
+{
+        qDebug() << "Removing database backup";
+        QFile::remove(backupPath);
+}
+
+
 bool DBManager::createTables()
 {
         bool ret;
         QSqlQuery query;
 
+        ret = query.exec("CREATE TABLE version (value integer primary key)");
+
+        if (!ret) {
+                qDebug() << "Error creating table version " << query.lastError();
+                return false;
+        }
+
+        ret = query.exec(QString("insert into version(value) values(%1)").arg(CURRENT_VERSION));
+        if (!ret) {
+                qDebug() << "Error inserting version value in tha database " << query.lastError();
+                return false;
+        }
+
         ret = query.exec("create table account ("
                          "id integer primary key autoincrement, "
                          "name text unique not null, "
@@ -59,6 +250,7 @@ bool DBManager::createTables()
 
         if (!ret) {
                 qDebug() << "\nError creating table account" << query.lastError();
+                return false;
         }
 
         ret = query.exec("create table month (year integer not null, "
@@ -92,6 +284,7 @@ bool DBManager::createTables()
 
         if (!ret) {
                 qDebug() << "\nError creating table expense" << query.lastError();
+                return false;
         }
 
         ret = query.exec("create table scheduled (id integer primary key autoincrement,"
@@ -579,31 +772,43 @@ bool DBManager::loadScheduled(int account, QStandardItemModel *scheduled)
         while (query.next()) {
                 QList<QStandardItem*> row;
                 QStandardItem *item;
+                //SCHEDULED_ID
                 item = new QStandardItem (query.value(0).toString());
                 item->setTextAlignment(Qt::AlignCenter);
                 item->setEditable(false);
                 row.append(item);
+                //SCHEDULED_DAY
                 item = new QStandardItem (query.value(1).toString());
                 item->setTextAlignment(Qt::AlignCenter);
                 item->setEditable(false);
                 row.append(item);
+                //SCHEDULED_DAY_AS_STRING
+                item = new QStandardItem (Expense::dayFrecuencyAsString(query.value(1).toInt()));
+                item->setTextAlignment(Qt::AlignCenter);
+                item->setEditable(false);
+                row.append(item);
+                //SCHEDULED_AMOUNT
                 item = new QStandardItem (query.value(2).toString());
                 item->setTextAlignment(Qt::AlignCenter);
                 item->setEditable(false);
                 row.append(item);
+                //SCHEDULED_CONCEPT
                 item = new QStandardItem (query.value(3).toString());
                 item->setTextAlignment(Qt::AlignLeft | Qt::AlignVCenter);
                 item->setEditable(false);
                 row.append(item);
+                //SCHEDULED_DESCRIPTION
                 item = new QStandardItem (query.value(4).toString());
                 item->setTextAlignment(Qt::AlignLeft | Qt::AlignVCenter);
                 item->setEditable(false);
                 row.append(item);
+                //SCHEDULED_MONTH
                 item = new QStandardItem (query.value(5).toString());
                 item->setTextAlignment(Qt::AlignCenter);
                 item->setEditable(false);
                 row.append(item);
-                item = new QStandardItem (Expense::frecuencyAsString(query.value(5).toInt()));
+                //SCHEDULED_MONTH_AS_STRING
+                item = new QStandardItem (Expense::monthFrecuencyAsString(query.value(5).toInt()));
                 item->setTextAlignment(Qt::AlignLeft | Qt::AlignVCenter);
                 item->setEditable(false);
                 row.append(item);
