@@ -57,10 +57,10 @@ int Expense::frecuency()
 }
 void Expense::addFrecuency(int frecuency)
 {
-        _frecuency |= 1 << frecuency - 1;
+        _frecuency |= 1 << (frecuency - 1);
 }
 
-QString Expense::frecuencyAsString (int frecuency)
+QString Expense::monthFrecuencyAsString (int frecuency)
 {
         QString string;
         int i;
@@ -78,3 +78,22 @@ QString Expense::frecuencyAsString (int frecuency)
         }
         return string;
 }
+
+QString Expense::dayFrecuencyAsString (int frecuency)
+{
+        QString string;
+        int i;
+        bool comma = false;
+
+        for (i = 0; i < 31; i++) {
+                if (frecuency & (1 << i)) {
+                        if (comma) {
+                                string.append(", ");
+                        } else {
+                                comma = true;
+                        }
+                        string += QString("%1").arg(i + 1);
+                }
+        }
+        return string;
+}
