@@ -24,7 +24,8 @@ class Expense : public QObject
         int frecuency();
         void addFrecuency(int frecuency);
 
-        static QString frecuencyAsString(int frecuency);
+        static QString monthFrecuencyAsString(int frecuency);
+        static QString dayFrecuencyAsString(int frecuency);
 
  private:
         int _id;
