@@ -3,7 +3,7 @@
 
 #include <QWidget>
 #include <QList>
-#include "monthdata.h"
+#include "expensesgraphmodel.h"
 
 class ExpensesGraph : public QWidget
 {
@@ -15,7 +15,7 @@ class ExpensesGraph : public QWidget
         QSize sizeHint() const;
 
         void setPadding(int padding);
-        void setMonthData(MonthData *month);
+        void setModel(ExpensesGraphModel *model);
         void setAccumulated(bool accumulated);
         bool accumulated();
 
@@ -33,15 +33,15 @@ class ExpensesGraph : public QWidget
 
         int _padding;
         bool _accumulated;
-        MonthData *_month;
+        ExpensesGraphModel *_model;
         int xStart, yStart;
         int sceneWidth, sceneHeight;
         int xEnd, yEnd;
         int xStepsPerLabel, yStepsPerLabel;
         int yMaxValue;
-        double dailyExpense;
         double xStep, yStep;
         double yScale;
+        int yLabelWidth;
 };
 
 
