@@ -2,21 +2,15 @@
 #define EXPENSESLIST_H
 
 #include <QWidget>
-#include <QStandardItemModel>
 #include <QModelIndex>
 
 class ExpensesList : public QWidget
 {
         Q_OBJECT
  public:
-        ExpensesList(QStandardItemModel *expenses,
-                     QWidget *parent = 0);
-        ~ExpensesList();
-
+        ExpensesList(QWidget *parent = 0);
  signals:
         void newExpenseSelected();
         void expenseDetailsSelected(QModelIndex index);
-
- private:
 };
 #endif
