@@ -4,16 +4,34 @@
 MonthData::MonthData(QDate date,
                      Account *account,
                      QObject *parent)
-        : QObject(parent)
+        : ExpensesGraphModel(parent)
 {
         _date = date;
         _account = account;
         _budget = account->budget();
+        _dailyExpense = _budget / _date.daysInMonth();
         _maxExpense = 0;
         _totalExpense = 0;
-        _summary.resize(_date.daysInMonth() + 1);
+        _summary.resize(_date.daysInMonth());
         _summary.fill(0);
         _expenses = new QStandardItemModel(0,5);
+
+#ifndef Q_WS_MAEMO_5
+        /* add headers to the model */
+        QStandardItem *header;
+        header = new QStandardItem (tr("Day"));
+        header->setTextAlignment(Qt::AlignCenter);
+        _expenses->setHorizontalHeaderItem(1, header);
+        header = new QStandardItem (tr("Amount"));
+        header->setTextAlignment(Qt::AlignCenter);
+        _expenses->setHorizontalHeaderItem(2, header);
+        header = new QStandardItem (tr("Item"));
+        header->setTextAlignment(Qt::AlignCenter);
+        _expenses->setHorizontalHeaderItem(3, header);
+        header = new QStandardItem (tr("Description"));
+        header->setTextAlignment(Qt::AlignCenter);
+        _expenses->setHorizontalHeaderItem(4, header);
+#endif
 }
 
 MonthData::~MonthData()
@@ -48,15 +66,17 @@ double MonthData::budget()
 void MonthData::setBudget(double budget)
 {
         _budget = budget;
+        _dailyExpense = _budget / _date.daysInMonth();
+
         emit budgetChanged();
 }
 
 void MonthData::addExpense(Expense *e)
 {
-        _summary[e->day()] += e->amount();
+        _summary[e->day() - 1] += e->amount();
         _totalExpense += e->amount();
-        if (_summary[e->day()] > _maxExpense) {
-                _maxExpense = _summary[e->day()];
+        if (_summary[e->day() - 1] > _maxExpense) {
+                _maxExpense = _summary[e->day() - 1];
         }
 
         QStandardItem *item;
@@ -85,7 +105,11 @@ void MonthData::addExpense(Expense *e)
 
         delete e;
 
-        emit expensesChanged();
+        if (notifyExpenses) {
+                emit expensesChanged();
+        } else {
+                pendingNotifications = true;
+        }
 }
 
 QStandardItemModel* MonthData::expenses()
@@ -124,9 +148,9 @@ QDate MonthData::date()
         return _date;
 }
 
-const QVector<double>& MonthData::summary()
+double MonthData::value(int index)
 {
-        return _summary;
+        return _summary[index];
 }
 
 void MonthData::clear()
@@ -136,5 +160,29 @@ void MonthData::clear()
         _maxExpense = 0;
         _totalExpense = 0;
 
-        emit expensesChanged();
+        if (notifyExpenses) {
+                emit expensesChanged();
+        } else {
+                pendingNotifications = true;
+        }
+}
+
+int MonthData::xDivisions()
+{
+        return _date.daysInMonth();
+}
+
+int MonthData::label(int index)
+{
+        return index + 1;
+}
+
+double MonthData::reference(int i)
+{
+        return _dailyExpense;
+}
+
+double MonthData::maxBudget()
+{
+        return _dailyExpense;
 }
