@@ -7,11 +7,12 @@
 #include <QStandardItemModel>
 #include <QDate>
 #include <QDebug>
+#include "expensesgraphmodel.h"
 #include "expense.h"
 #include "global.h"
 #include "account.h"
 
-class MonthData : public QObject
+class MonthData : public ExpensesGraphModel
 {
         Q_OBJECT
  public:
@@ -30,16 +31,18 @@ class MonthData : public QObject
         double maxExpense();
         double totalExpense();
         QStandardItemModel* expenses();
-        const QVector<double>& summary();
+        double value(int i);
         QDate next();
         QDate previous();
         bool isCurrent();
         QDate date();
         void clear();
+        int xDivisions();
+        int label(int i);
+        double reference(int i);
+        double maxBudget();
 
  signals:
-        void expensesChanged();
-        void budgetChanged();
 
  private:
 
@@ -50,6 +53,7 @@ class MonthData : public QObject
         QStandardItemModel *_expenses;
         double _maxExpense;
         double _totalExpense;
+        double _dailyExpense;
 };
 
 #endif
