@@ -2,21 +2,16 @@
 #define SCHEDULEDLIST_H
 
 #include <QWidget>
-#include <QStandardItemModel>
 #include <QModelIndex>
 
 class ScheduledList : public QWidget
 {
         Q_OBJECT
  public:
-        ScheduledList(QStandardItemModel *scheduled,
-                     QWidget *parent = 0);
-        ~ScheduledList();
+        ScheduledList(QWidget *parent = 0);
 
  signals:
         void newScheduledSelected();
         void scheduledDetailsSelected(QModelIndex index);
-
- private:
 };
 #endif
