@@ -3,16 +3,18 @@
 
 #include <QObject>
 #include <QList>
+#include "expensesgraphmodel.h"
 #include "concept.h"
 
-class SummaryData : public QObject
+class SummaryData : public ExpensesGraphModel
 {
         Q_OBJECT
  public:
         SummaryData(int startYear,
                     int startMonth,
                     int endYear,
-                    int endMonth);
+                    int endMonth,
+                    QObject *parent = 0);
         ~SummaryData();
 
         int startYear();
@@ -33,6 +35,15 @@ class SummaryData : public QObject
         void addMonthData(double budget, double expense);
         void addConcept(Concept *c);
 
+        /* form ExpensesGraphModel */
+        double budget();
+        bool isCurrent();
+        int xDivisions();
+        double value(int i);
+        int label(int i);
+        double reference(int i);
+        double maxBudget();
+
         const QList<Concept*>& concepts();
 
  private:
@@ -49,10 +60,13 @@ class SummaryData : public QObject
         double _minExpense;
         double _minSaved;
         double _maxSaved;
+        double _maxBudget;
 
         int _monthCount;
 
         QList<Concept*> _concepts;
+        QList<double> _values;
+        QList<double> _references;
 };
 
 #endif
